# Generated by Django 4.2.16 on 2024-10-06 16:39

# Django
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("auth", "0012_alter_user_first_name_max_length"),
        ("aa_forum", "0017_ckeditor5_and_dashboard_widgets"),
    ]

    operations = [
        migrations.AlterField(
            model_name="board",
            name="announcement_groups",
            field=models.ManyToManyField(
                blank=True,
                help_text='User in at least one of the selected groups will be able to start topics in "Announcement Boards". If no group is selected, only forum admins can do so. This setting will not be inherited to child boards. (Hint: These restrictions only take effect when a board is marked as "Announcement Board", see checkbox above.)',
                related_name="aa_forum_boards_group_start_topic_restriction",
                to="auth.group",
            ),
        ),
        migrations.AlterField(
            model_name="board",
            name="description",
            field=models.TextField(
                blank=True, help_text="Board description (optional)"
            ),
        ),
        migrations.AlterField(
            model_name="board",
            name="discord_webhook",
            field=models.CharField(
                blank=True,
                default=None,
                help_text="Discord webhook URL for the channel to post about new topics in this board. (This setting is optional)",
                max_length=254,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="board",
            name="groups",
            field=models.ManyToManyField(
                blank=True,
                help_text="This will restrict access to this board to the selected groups. If no groups are selected, everyone who can access the forum can also access this board. (This setting is optional)",
                related_name="aa_forum_boards_group_restriction",
                to="auth.group",
            ),
        ),
        migrations.AlterField(
            model_name="board",
            name="is_announcement_board",
            field=models.BooleanField(
                default=False,
                help_text='Mark this board as an "Announcement Board", meaning that only certain selected groups can start new topics. All others who have access to this board will still be able to discuss in the topics though. This setting will not be inherited to child boards. (Default: NO)',
            ),
        ),
        migrations.AlterField(
            model_name="setting",
            name="messages_per_page",
            field=models.IntegerField(
                default=15,
                help_text="How many messages per page should be displayed in a forum topic? (Default: 15)",
                verbose_name="Messages per page",
            ),
        ),
        migrations.AlterField(
            model_name="setting",
            name="topics_per_page",
            field=models.IntegerField(
                default=10,
                help_text="How many topics per page should be displayed in a forum category? (Default: 10)",
                verbose_name="Topics per page",
            ),
        ),
        migrations.AlterField(
            model_name="setting",
            name="user_signature_length",
            field=models.IntegerField(
                default=750,
                help_text="How long (Number of characters) is a user's signature allowed to be? (Default: 750)",
                verbose_name="User signature length",
            ),
        ),
    ]
